@@ -51,8 +51,11 @@ from .helper import (
 )
 from .new_helper import (
     ChatOrgAsync,
+    ChatsCohereAsync,
+    ChatsGeminiAsync,
     ChatsOpenAIAsync,
     ChatsQwenAsync,
+    ImagesOpenAIAsync,
     ImagesOrgAsync,
     ImagesQwenAsync,
     VideosQwenAsync,
@@ -70,6 +73,9 @@ class RyzenthOrg:
         self._api_key = api_key
         self._session = None
         self._closed = False
+        self.cohere_chat = ChatsCohereAsync(self)
+        self.gemini_chat = ChatsGeminiAsync(self)
+        self.openai_images = ImagesOpenAIAsync(self)
         self.openai_responses = ChatsOpenAIAsync(self)
         self.qwen_chat = ChatsQwenAsync(self)
         self.qwen_images = ImagesQwenAsync(self)
