@@ -1,6 +1,9 @@
-from ._chats import ChatOrgAsync
-from ._images import ImagesOrgAsync
+from ._cohere_chats import ChatsCohereAsync
+from ._default_chats import ChatOrgAsync
+from ._default_images import ImagesOrgAsync
+from ._gemini_chats import ChatsGeminiAsync
 from ._openai_chats import ChatsOpenAIAsync
+from ._openai_images import ImagesOpenAIAsync
 from ._qwen_chats import ChatsQwenAsync
 from ._qwen_images import ImagesQwenAsync
 from ._qwen_videos import VideosQwenAsync
@@ -9,8 +12,11 @@ __all__ = [
   "ChatOrgAsync",
   "ChatsQwenAsync",
   "ChatsOpenAIAsync",
+  "ChatsGeminiAsync",
+  "ChatsCohereAsync",
   "ImagesQwenAsync",
   "ImagesOrgAsync",
+  "ImagesOpenAIAsync",
   "VideosQwenAsync"
 ]
 
